@@ -34,6 +34,8 @@ class Profile():
         and right phase bin of off pulse phases.
         left_edge = phase_off[0]
         right_edge = phase_ff[1]
+    ref_time : float, default None
+        The reference time (in second) used to fold the profile
     """
 
     def __init__(self, counts, cycles=1, error=None):
@@ -70,6 +72,7 @@ class Profile():
             self.error = error
         self._cycles = cycles
         self._pickled = False # whether the profile has been duplicated or modified
+        self.ref_time = None
 
     def __add__(self, other):
         """
@@ -238,3 +241,35 @@ def phihist(phi, nbins, **kwargs):
     profile_object = Profile(counts, **kwargs)
 
     return profile_object
+
+# If the code works fine, don't easily modify/delete it
+def resampling_profile(profile, sample_num=1, kind='poisson'):
+     '''
+     resampling the profile
+     Parameters
+     ----------
+     profile : array
+         The un-normalized profile
+     sample_num : int, optional
+         number of the resamplings for the profile, the default number is 1
+     kind : str, optional
+         The distribution of the profile, default is poisson.
+         ('poisson', 'gaussian') are refering to the poisson and gauss distribution
+     Returns
+     -------
+     resampled_profile : array or ndarray
+         if sample_num == 1, return a one dimensional array
+         if sample_num >1 , return a multi-dimensional array
+     '''
+     raw_profile = np.array(profile.tolist()*sample_num)
+     if sample_num <= 0:
+         raiseError("The number of sampling must a positive integer")
+
+     if kind == "poisson":
+         resampled_profile = np.random.poisson(raw_profile)
+     elif kind == "gaussian":
+         pass #TODO
+
+     resampled_profile = resampled_profile.reshape(int(len(resampled_profile)/len(profile)),
+             int(len(profile)))
+     return resampled_profile
